#  Contributor's Guide

Interested in contributing? Awesome!

well.

There are many ways you can contribute! :heart:

###  Bug Reports and Fixes :bug:

- If you find a bug, please search for it in the [Issues][gh-issues], and if it isn't already tracked, [create a new issue][gh-new-issue]. Fill out the "Bug Report" section of the issue template. Even if an Issue is closed, feel free to comment and add details, it will still be reviewed.

- Issues that have already been identified as a bug (note: able to reproduce) will be labelled `bug`.

- If you'd like to submit a fix for a bug, [send a Pull Request](#creating-a-pull-request) and mention the Issue number.

- Include tests that isolate the bug and verifies that it was fixed.

###  New Features :bulb:

- If you'd like to add new functionality to this project, describe the problem you want to solve in a [new Issue][gh-new-issue].

- Issues that have been identified as a feature request will be labelled `enhancement`.

- If you'd like to implement the new feature, please wait for feedback from the project maintainer before spending too much time writing the code. In some cases, `enhancement`'s may not align well with the project objectives at the time.

###  Tests :mag:, Documentation :books:, Miscellaneous :sparkles:

- If you'd like to improve the tests, you want to make the documentation clearer, you have an alternative implementation of something that may have advantages over the way its currently done, or you have any other change, we would be happy to hear about it!

- If its a trivial change, go ahead and [send a Pull Request](#creating_a_pull_request) with the changes you have in mind.

- If not, [open an Issue][gh-new-issue] to discuss the idea first.

##  Requirements

For your contribution to be accepted:

- [x] The changes must be approved by code review.

- [x] Commits should be atomic and messages must be descriptive. Related issues should be mentioned by Issue number.

If the contribution doesn't meet the above criteria, a maintainer will discuss it with you. You can continue to improve a Pull Request by adding commits to the branch from which the PR was created.

##  Creating a Pull Request

1. :fork_and_knife: Fork the repository on GitHub.

2. :runner: Clone/fetch your fork to your local development machine. It's a good idea to run the tests just

to make sure everything is in order.

3. :herb: Create a new branch and check it out.

4. :crystal_ball: Make your changes and commit them locally. Magic happens here!

5. :arrow_heading_up: Push your new branch to your fork. (e.g. `git push username fix-issue-16`).

6. :inbox_tray: Open a Pull Request on github.com from your new branch on your fork to `development` branch in this repository.

_NOTE: Any PRs to Main branch will not be accepted. Please raise PR to `development` branch only_

Happy Coding! :star:


<!-- Markdown link -->
[gh-issues]: https://github.com/siddheshgunjal/slackker/issues
[gh-new-issue]: https://github.com/siddheshgunjal/slackker/issues/new
